@@ -16,8 +16,9 @@
 # limitations under the License.
 
 """
-Package for parsing ``Authentication-Results`` headers as defined in RFC 5451.
-Optional support for authentication methods defined in RFCs 5617, 6008, and 6212.
+Package for parsing ``Authentication-Results`` headers as defined in RFC
+5451/7001.  Optional support for authentication methods defined in RFCs 5617,
+6008, 6212, and 7281.
 
 Examples:
 RFC 5451 B.2
@@ -93,7 +94,7 @@ MODULE = 'authres'
 
 __author__  = 'Julian Mehnle, Scott Kitterman'
 __email__   = 'julian@mehnle.net'
-__version__ = '0.602'
+__version__ = '0.700'
 
 import authres.core
 
@@ -182,11 +183,13 @@ def all_features():
         import authres.dkim_adsp
         import authres.vbr
         import authres.dmarc
+        import authres.smime
         _all_features = FeatureContext(
             authres.dkim_b,
             authres.dkim_adsp,
             authres.vbr,
-            authres.dmarc
+            authres.dmarc,
+            authres.smime
         )
     return _all_features
 
