@@ -16,13 +16,14 @@
 # limitations under the License.
 
 """
-Package for parsing ``Authentication-Results`` headers as defined in RFC 5451.
-Optional support for authentication methods defined in RFCs 5617, 6008, and 6212.
+Package for parsing ``Authentication-Results`` headers as defined in RFC
+5451/7001.  Optional support for authentication methods defined in RFCs 5617,
+6008, 6212, and 7281.
 """
 
 __author__  = 'Julian Mehnle, Scott Kitterman'
 __email__   = 'scott@kitterman.com'
-__version__ = '0.602'
+__version__ = '0.700'
 
 def _test():
     import doctest
